mpn_elite_usa_advice is a 2-mode network of persons serving as directors or trustees of think tanks. Think tanks are “public-policy research analysis and engagement organizations that generate policy-oriented research, analysis, and advice on domestic and international issues, thereby enabling policymakers and the public to make informed decisions about public policy” (McGann 2016: 6). The Power Elite Database (Domhoff 2016) includes information on the directors of 33 prominent think tanks in 2012. Here we include only 14 directors who held three or more seats among 20 think tanks.

mpn_elite_usa_money is based on 26 elites who sat on the boards of directors for at least two of six economic policy making organizations (Domhoff 2016), and also made campaign contributions to one or more of six candidates running in the primary election contests for the 2008 Presidential nominations of the Republican Party (Rudy Giuliani, John McCain, Mitt Romney) or the Democratic Party (Hillary Clinton, Christopher Dodd, Barack Obama).

data(mpn_elite_usa_advice)

data(mpn_elite_usa_money)

Format

#> -- # US think tank board network -----------------------------------------------
#> # A labelled, two-mode network of 14 directors and 20 think tanks and 46 board
#> membership ties
#>
#> -- Nodes
#> # A tibble: 34 x 2
#>   label    mode
#>   <chr>    <chr>
#> 1 Albright directors
#> 2 Argyros  directors
#> 3 Armitage directors
#> 4 Curry    directors
#> 5 Fukuyama directors
#> 6 Gray     directors
#> # i 28 more rows
#>
#> -- Ties
#> # A tibble: 46 x 2
#>    from    to
#>   <int> <int>
#> 1     1    17
#> 2     1    19
#> 3     1    21
#> 4     2    22
#> 5     2    23
#> 6     2    27
#> # i 40 more rows
#>

#> -- # US power elite network ----------------------------------------------------
#> # A labelled, multiplex, undirected network of 38 elites and 59 board
#> membership ties and 44 campaign contribution ties
#>
#> -- Nodes
#> # A tibble: 38 x 2
#>   label    mode
#>   <chr>    <chr>
#> 1 Adkerson elites
#> 2 Akins    elites
#> 3 Banga    elites
#> 4 Boyce    elites
#> 5 Britt    elites
#> 6 Cannon   elites
#> # i 32 more rows
#>
#> -- Ties
#> # A tibble: 103 x 3
#>    from    to layer
#>   <int> <int> <chr>
#> 1     1    27 board membership
#> 2     3    27 board membership
#> 3     4    27 board membership
#> 4     5    27 board membership
#> 5     7    27 board membership
#> 6     9    27 board membership
#> # i 97 more rows
#>

Details

Figure: mpn_elite_usa

References

Domhoff, G William. 2016. “Who Rules America? Power Elite Database.”

The Center for Responsive Politics. 2019. “OpenSecrets.” https://www.opensecrets.org.

Knoke, David, Mario Diani, James Hollway, and Dimitris C Christopoulos. 2021. Multimodal Political Networks. Cambridge University Press. Cambridge University Press.