test_tutorials: Test tutorials

View source: R/tutorial_test.R

test_tutorialsR Documentation

Test tutorials

Description

For our purposes, "testing" a tutorial means being able to (successfully) run render() on it. This function renders the tutorial provided in path. There is no check to see if the rendered file looks OK. If a tutorial fails to render, then an error will be generated which will propagate to the caller.

Usage

test_tutorials(path, quiet = TRUE)

Arguments

path

Character vector of the paths to the tutorials to be knitted.

quiet

Logical, whether to suppress messages from render().

Value

No return value, called for side effects.

Author(s)

David Kane, see tutorial.helpers


migraph documentation built on April 4, 2026, 5:07 p.m.