Superseded. These three datasets are superseded by mpn_senate,
which holds the same data as one multilevel network with a community
node attribute. They are kept for one release and will be removed in 1.8.0.
These datasets list the U.S. Senators who served in the 112th Congress, which met from January 3, 2011 to January 3, 2013. Although the Senate has 100 seats, 103 persons served during this period due to two resignations and a death. However, the third replacement occurred only two days before the end and cast no votes on the bills investigated here. Hence, the number of Senators analyzed is 102.
CQ Almanac identified 25 key bills on which the Senate voted during the 112th Congress, and which Democratic and Republican Senators voting “yea” and “nay” on each proposal.
Lastly, we obtained data on campaign contributions made by 92 PACs from the Open Secrets Website. We recorded all contributions made during the 2008, 2010, and 2012 election campaigns to the 102 persons who were Senators in the 112th Congress. The vast majority of PAC contributions to a candidate during a campaign was for $10,000 (the legal maximum is $5,000 each for a primary and the general election). We aggregated the contributions across all three electoral cycles, then dichotomized the sums into no contribution (0) and any contribution (1).
#> -- # Senate community A --------------------------------------------------------
#> # A labelled, undirected network of 114 senators and 2791 contribution and vote
#> ties
#>
#> -- Nodes
#> # A tibble: 114 x 2
#> label mode
#> <chr> <chr>
#> 1 Baucus senators
#> 2 Begich senators
#> 3 Bennet senators
#> 4 Blumenthal senators
#> 5 Boxer senators
#> 6 BrownSh senators
#> # i 108 more rows
#>
#> -- Ties
#> # A tibble: 2,791 x 2
#> from to
#> <int> <int>
#> 1 1 52
#> 2 1 53
#> 3 1 54
#> 4 1 55
#> 5 1 56
#> 6 1 57
#> # i 2,785 more rows
#>#> -- # Senate community B --------------------------------------------------------
#> # A labelled, undirected network of 134 senators and 3675 contribution and vote
#> ties
#>
#> -- Nodes
#> # A tibble: 134 x 2
#> label mode
#> <chr> <chr>
#> 1 Alexander senators
#> 2 Ayotte senators
#> 3 Barrasso senators
#> 4 Baucus senators
#> 5 Blunt senators
#> 6 Boozman senators
#> # i 128 more rows
#>
#> -- Ties
#> # A tibble: 3,675 x 2
#> from to
#> <int> <int>
#> 1 1 64
#> 2 1 66
#> 3 1 67
#> 4 1 70
#> 5 1 71
#> 6 1 72
#> # i 3,669 more rows
#>#> -- # Senate community overlap --------------------------------------------------
#> # A labelled, undirected network of 52 senators and 614 contribution and vote
#> ties
#>
#> -- Nodes
#> # A tibble: 52 x 2
#> label mode
#> <chr> <chr>
#> 1 Baucus senators
#> 2 Cardin senators
#> 3 Carper senators
#> 4 Casey senators
#> 5 Collins senators
#> 6 Feinstein senators
#> # i 46 more rows
#>
#> -- Ties
#> # A tibble: 614 x 2
#> from to
#> <int> <int>
#> 1 1 21
#> 2 1 22
#> 3 1 23
#> 4 1 24
#> 5 1 25
#> 6 1 26
#> # i 608 more rows
#>Knoke, David, Mario Diani, James Hollway, and Dimitris C Christopoulos. 2021. Multimodal Political Networks. Cambridge University Press. Cambridge University Press.