For our purposes, "testing" a tutorial means being able to
(successfully) run render() on it.
This function renders the tutorial provided in path.
There is no check to see if the rendered file looks OK.
If a tutorial fails to render, then an error will be generated which will
propagate to the caller.
test_tutorials(path, quiet = TRUE)No return value, called for side effects.